@@ -99,40 +99,65 @@ def seeing_to_r0(seeing, lamda=500.E-9):
     return 0.98*lamda/(seeing*numpy.pi/(180.*3600.))
 
 
-def coherenceTime(cn2, v, lamda=500.E-9):
+def coherenceTime(cn2, v, lamda=500.E-9, axis=-1):
     """
     Calculates the coherence time from profiles of the Cn2 and wind velocity
 
     Parameters:
-        cn2 (array): Cn2 profile in m^2/3
+        cn2 (array): Cn2 profile in m^2/3. >1D arrays are supported (i.e. multiple
+            profiles), in which case the default assumption is that the turbulent 
+            layers are along the final (-1) axis. 
         v (array): profile of wind velocity, same altitude scale as cn2 
         lamda : wavelength
+        axis (int, optional): axis over which to integrate (for >1D inputs)
 
     Returns:
         coherence time in seconds
     """
-    Jv = (cn2*(v**(5./3.))).sum()
-    tau0 = float((Jv**(-3./5.))*0.057*lamda**(6./5.))
+    Jv = (cn2*(v**(5./3.))).sum(axis)
+    tau0 = (Jv**(-3./5.))*0.057*lamda**(6./5.)
     return tau0
 
 
-def isoplanaticAngle(cn2, h, lamda=500.E-9):
+def isoplanaticAngle(cn2, h, lamda=500.E-9, axis=-1):
     """
     Calculates the isoplanatic angle from the Cn2 profile
 
     Parameters:
-        cn2 (array): Cn2 profile in m^2/3
+        cn2 (array): Cn2 profile in m^2/3.  >1D arrays are supported (i.e. multiple
+            profiles), in which case the default assumption is that the turbulent 
+            layers are along the final (-1) axis. 
         h (Array): Altitude levels of cn2 profile in m
         lamda : wavelength
+        axis (int, optional): axis over which to integrate (for >1D inputs)
 
     Returns:
         isoplanatic angle in arcseconds
     """
-    Jh = (cn2*(h**(5./3.))).sum()
-    iso = float(0.057*lamda**(6./5.)*Jh**(-3./5.)*180.*3600./numpy.pi)
+    Jh = (cn2*(h**(5./3.))).sum(axis)
+    iso = 0.057*lamda**(6./5.)*Jh**(-3./5.)*180.*3600./numpy.pi
     return iso
 
 
+def rytov_variance(cn2, h, lamda=500.E-9, axis=-1):
+    """
+    Calculates plane wave Rytov variance from the Cn2 profile
+
+    Parameters:
+        cn2 (numpy.ndarray): Cn2 profile in m^2/3.  >1D arrays are supported (i.e. multiple
+            profiles), in which case the default assumption is that the turbulent 
+            layers are along the final (-1) axis. 
+        h (numpy.ndarray): Altitude levels of cn2 profile in m
+        lamda (float, optional): wavelength, default 500 nm
+        axis (int, optional): axis over which to integrate (for >1D inputs)
+
+    Returns:
+        Rytov variance (float)
+    """
+    k = 2. * numpy.pi / lamda
+    return 2.25 * k**(7./6.) * (cn2*h**(5./6.)).sum(axis)
+
+
 def r0_from_slopes(slopes, wavelength, subapDiam):
     """
     Measures the value of R0 from a set of WFS slopes.
@@ -152,7 +177,7 @@ def r0_from_slopes(slopes, wavelength, subapDiam):
 
     r0 = ((0.162 * (wavelength ** 2) * subapDiam ** (-1. / 3)) / slopeVar) ** (3. / 5)
 
-    r0 = float(r0.mean())
+    r0 = r0.mean()
 
     return r0
 
